/**
 * \addtogroup Sio_poll
 * @{
 */

/*****************************************************************************/
/**
 * \file Sio_poll.c
 * Low level 8051 serial input/ output routines for Keil C51.
 * \author Copyright (c) 2008, Murray R. Van Luyn. <vanluynm@iinet.net.au>
 * \version 0.5
 * \date 28-02-08
 */
/*****************************************************************************/

/*****************************************************************************
 *
 *     THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 *     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *     ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 *     DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *     DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *     GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *     NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/


#include "Sio_poll.h"


/*****************************************************************************
 *
 *                         Public Function Implementation
 *
 *****************************************************************************/

/*****************************************************************************
 *
 *                              init_sio_poll()
 *
 *****************************************************************************/
void init_sio_poll(unsigned int baud_rate)
{
    TR1  = 0;                       // Halt Timer 1.
    ET1  = 0;                       // Disable Timer 1 interrupt
    TMOD &= 0x0F;                   // Setup timer/counter 1 for mode 2
    TMOD |= 0x20;                   // 8-bit auto-reload timer.

    if (baud_rate >= 19200)         // Enable baud rates beyond 19200 bps
	{
        baud_rate = baud_rate >> 1; // Halve requested rate
		PCON |= 0x80;               // Turn SMOD1 on to double baud
                                    // rate in modes 1, 2 & 3
	}

    TH1  = 256 - ((T1_CLOCK / 32) / baud_rate);
                                    // Set timer/counter 1 reload count.
    TR1  = 1;                       // Start timer/counter 1. It will free run
    SCON = 0x50;                    // Set port 1 for mode 1: 8N1 operation
    TI   = 1;                       // Set TI to indicate TX buffer empty

    delay_ms(10);                   // Allow hardware to settle

    return;
}


/*****************************************************************************
 *
 *                                 putchar()
 *
 *****************************************************************************/
char putchar(char outChar)
{
    while(!TI);               // Wait till last character sent
    TI = 0;                   // Clear TI to indicate TX buffer full
    SBUF = outChar;           // Next character to send into sio

    return outChar;
}


/*****************************************************************************
 *
 *                                 _getkey()
 *
 *****************************************************************************/
char _getkey(void)
{
    char inChar;

    while(!RI);               // Wait until a character received
    inChar = SBUF;            // Read input character
    RI = 0;                   // Clear RI to indicate reception

    return inChar;
}

/** @} */
