/**
 * \addtogroup Sio_poll
 * @{
 */

/*****************************************************************************/
/**
 * \file Sio_poll.h
 * Low level 8051 serial input/ output routines for Keil C51.
 * \author Copyright (c) 2008, Murray R. Van Luyn. <vanluynm@iinet.net.au>
 * \version 0.5
 * \date 28-02-08
 */
/*****************************************************************************/

/*****************************************************************************
 *
 *     THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 *     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *     ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 *     DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *     DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *     GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *     NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/


#ifndef SIO_POLL_H
#define SIO_POLL_H

#include <REG51.h>
#include "Delay.h"

/** 
 * Hardware crystal frequency in Hz.
 * Adjust \b XTAL to match hardware.
 * \hideinitializer
 */
#define XTAL                 22118400   

/*
 * Timer 1 mode 2 clock rate.
 */
#define T1_CLOCK             XTAL / 12   


/*****************************************************************************
 *
 *                           Public Function Prototypes
 *
 *****************************************************************************/

/** 
 * Sio initialisation function.
 * Initialises the 8051 serial port for polled, specified baud rate 8N1 
 * operation. Must be called once to set-up serial hardware prior to then
 * calling any high level functions (printf(), scanf(), etc.) that use the
 * low level serial routines, or before calling the low level routines
 * directly.
 * \param baud_rate the \b unsigned \b int selected baud rate.
 * \return -
 */
void init_sio_poll(unsigned int baud_rate);


/** 
 * Sio character transmission function.
 * The %putchar() function transmits the character \a outChar using the 8051
 * serial port, and returns the character output.
 * The %putchar() function is called by high level routines like puts() and
 * printf(), and may also be called directly.
 * \param outChar the \b char to transmit.
 * \return the \b char transmitted.
 */
char putchar(char outChar); 


/**
 * Sio character reception function.
 * The %_getkey() function waits for a character to be received from the serial
 * port, and returns the received character.
 * The %_getkey() function is called by high level routines like getchar() and
 * scanf(), and may also be called directly.
 * \param -
 * \return the received \b char.
 */
char _getkey(void);


#endif

/** @} */
